<?php


//START ELEMENT EVENTS GRID
class nd_elements_eventsgrid_element extends \Elementor\Widget_Base {

	public function get_name() { return 'eventsgrid'; }
	public function get_title() { return __( 'Events Grid', 'nd-elements' ); }
	public function get_icon() { return 'fa fa-calendar'; }
	public function get_categories() { return [ 'nd-elements' ]; }

	
	/*START CONTROLS*/
	protected function _register_controls() {

	
		/*Create Tab*/
		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Main Options', 'nd-elements' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'eventsgrid_order',
			[
				'label' => __( 'Order', 'nd-elements' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => [
					'DESC'  => __( 'DESC', 'nd-elements' ),
					'ASC' => __( 'ASC', 'nd-elements' ),
				],
			]
		);

		$this->add_control(
			'eventsgrid_orderby',
			[
				'label' => __( 'Order By', 'nd-elements' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'ID'  => __( 'ID', 'nd-elements' ),
					'author' => __( 'Author', 'nd-elements' ),
					'title'  => __( 'Title', 'nd-elements' ),
					'name' => __( 'Name', 'nd-elements' ),
					'type'  => __( 'Type', 'nd-elements' ),
					'date' => __( 'Date', 'nd-elements' ),
					'modified'  => __( 'Modified', 'nd-elements' ),
					'rand' => __( 'Random', 'nd-elements' ),
					'comment_count'  => __( 'Comment Count', 'nd-elements' ),
				],
			]
		);

		$this->add_control(
			'eventsgrid_qnt',
			[
				'label' => __( 'Events Per Page', 'nd-elements' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => -1,
				'max' => 20,
				'step' => 1,
				'default' => 3,
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'style_section',
			[
				'label' => __( 'Style', 'nd-elements' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'eventsgrid_color_btn',
			[
				'label' => __( 'Button Color', 'nd-elements' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Scheme_Color::get_type(),
					'value' => \Elementor\Scheme_Color::COLOR_1,
				],
				'default' => '#000000',
			]
		);

		$this->add_control(
			'eventsgrid_color_time',
			[
				'label' => __( 'Time Color', 'nd-elements' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Scheme_Color::get_type(),
					'value' => \Elementor\Scheme_Color::COLOR_1,
				],
				'default' => '#000000',
			]
		);

		$this->end_controls_section();
		

	}
	//END CONTROLS


 
	/*START RENDER*/
	protected function render() {

		$nd_elements_result = '';

  		//get datas
  		$nd_elements_settings = $this->get_settings_for_display();
		$nd_elements_eventsgrid_order = $nd_elements_settings['eventsgrid_order'];
		$nd_elements_eventsgrid_orderby = $nd_elements_settings['eventsgrid_orderby'];
		$eventsgrid_qnt = $nd_elements_settings['eventsgrid_qnt'];
		$eventsgrid_color_btn = $nd_elements_settings['eventsgrid_color_btn'];
		$eventsgrid_color_time = $nd_elements_settings['eventsgrid_color_time'];

		//default values
		if ($eventsgrid_qnt == '') { $eventsgrid_qnt = 3; }
		if ($nd_elements_eventsgrid_order == '') { $nd_elements_eventsgrid_order = 'DESC'; }
		if ($nd_elements_eventsgrid_orderby == '') { $nd_elements_eventsgrid_orderby = 'date'; }

		//args
		$args = array(
			'post_type'=>array(TribeEvents::POSTTYPE),
			'posts_per_page' => $eventsgrid_qnt,
			'order' => $nd_elements_eventsgrid_order,
			'orderby' => $nd_elements_eventsgrid_orderby,
		);
		$the_query = new WP_Query( $args );

		//START LAYOUT
		$nd_elements_result .= '
		<div class="nd_elements_section">';

			while ( $the_query->have_posts() ) : $the_query->the_post();

				//info
				$nd_elements_id = get_the_ID(); 
				$nd_elements_title = get_the_title();
				$nd_elements_excerpt = get_the_excerpt();
				$nd_elements_permalink = get_permalink( $nd_elements_id );

				//image
				$nd_elements_image_id = get_post_thumbnail_id( $nd_elements_id );
				$nd_elements_image_attributes = wp_get_attachment_image_src( $nd_elements_image_id, 'thumbnail' );
				if ( $nd_elements_image_attributes[0] == '' ) { $nd_elements_output_image = ''; }else{
				  $nd_elements_output_image = '

				  <div class="nd_elements_width_100 nd_elements_display_table_cell nd_elements_display_inline_iphone nd_elements_float_left_iphone nd_elements_width_100_percentage_iphone nd_elements_vertical_align_middle nd_elements_position_relative">
				  	
				  	<a href="'.$nd_elements_permalink.'"><img width="100" class="nd_elements_float_left" alt="" src="'.$nd_elements_image_attributes[0].'"></a>
				  
				  	<div class="nd_elements_section nd_elements_text_align_center nd_elements_width_100 nd_elements_position_absolute nd_elements_bottom_10_negative">
				  		<a href="'.$nd_elements_permalink.'"><p style="background-color:'.$eventsgrid_color_time.';" class="nd_elements_display_inline_block nd_elements_margin_0_important nd_elements_padding_5_10 nd_elements_font_size_11 nd_elements_line_height_11 nd_options_color_white">'.tribe_get_start_date($nd_options_id,false,'g:i A').'</p></a>
				  	</div>
				  
				  </div>

				  ';
				}

				$nd_elements_result .= '
	    		<div class="nd_elements_section nd_elements_display_table nd_elements_padding_15 nd_elements_box_sizing_border_box">

	    			<div class=" nd_elements_width_30_percentage nd_elements_width_100_percentage_responsive nd_elements_float_left_responsive nd_elements_display_table_cell nd_elements_display_inline_responsive nd_elements_vertical_align_middle">
	    				

	    				<div class="nd_elements_section nd_elements_display_table">

	    					'.$nd_elements_output_image.'

	    					<div class="nd_elements_display_table_cell nd_elements_display_inline_iphone nd_elements_float_left_iphone nd_elements_width_100_percentage_iphone nd_elements_vertical_align_middle nd_elements_padding_left_50 nd_elements_padding_left_0_iphone nd_elements_margin_top_20_iphone">
			    				<a href="'.$nd_elements_permalink.'"><h3 class="nd_elements_margin_0_important nd_elements_font_size_23 nd_elements_line_height_1_2">'.$nd_elements_title.'</h3></a>
			    				<div class="nd_elements_section nd_elements_height_10"></div>
			    				<a href="'.$nd_elements_permalink.'"><h6 class="nd_elements_margin_0_important nd_options_color_grey nd_elements_font_size_15 nd_elements_line_height_15">'.tribe_get_start_date($nd_options_id,false,'d M Y').'</h6></a>
			    			</div>

	    				</div>

	    			</div>
	    			
	    			<div class=" nd_elements_width_50_percentage nd_elements_margin_top_20_responsive nd_elements_margin_bottom_20_responsive nd_elements_width_100_percentage_responsive nd_elements_float_left_responsive nd_elements_display_table_cell nd_elements_display_inline_responsive nd_elements_vertical_align_middle nd_elements_padding_left_50 nd_elements_padding_left_0_responsive">
	    				'.$nd_elements_excerpt.'
	    			</div>

	    			<div class=" nd_elements_width_20_percentage nd_elements_width_100_percentage_responsive nd_elements_float_left_responsive nd_elements_display_table_cell nd_elements_display_inline_responsive nd_elements_vertical_align_middle">
	    				<a style="background-color:'.$eventsgrid_color_btn.';" class="nd_elements_margin_bottom_20_responsive nd_options_color_white nd_elements_padding_10_20 nd_elements_font_size_10 nd_elements_line_height_10 nd_elements_float_right nd_elements_float_left_responsive" href="'.$nd_elements_permalink.'"><strong>'.__('VIEW DETAILS','nd-elements').'</strong></a>
	    			</div>

		    	</div>
			    ';

			endwhile;

		$nd_elements_result .= '
		</div>';
		//END LAYOUT

		wp_reset_postdata();

		echo $nd_elements_result;

	}
	//END RENDER


}
//END ELEMENT EVENTS GRID
